# ✨ Gen TSO ✨
### A general ETC interface for time-series observations with JWST

(Getting there...)

<!--
[![Tests](https://github.com/pcubillos/gen_tso/actions/workflows/python-package.yml/badge.svg?branch=master)](https://github.com/pcubillos/gen_tso/actions/workflows/python-package.yml)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/gen_tso.svg)](https://anaconda.org/conda-forge/gen_tso)
-->

[![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/pcubillos/gen_tso/quarto-publish.yml?label=docs)](https://pcubillos.github.io/gen_tso/)
[![PyPI](https://img.shields.io/pypi/v/gen_tso.svg)](https://pypi.org/project/gen_tso)
[![GitHub](https://img.shields.io/github/license/pcubillos/gen_tso.svg?color=blue)](https://github.com/pcubillos/gen_tso/blob/master/LICENSE)

### Install as:

Not yet on PyPI or Conda, but for the moment you can get the code from Github:
```
git clone https://github.com/pcubillos/gen_tso/
cd gen_tso
pip install .
```

Then setup the pandeia reference files following these instructions: [https://pcubillos.github.io/gen_tso/install.html](https://pcubillos.github.io/gen_tso/install.html#pandeia-engine-installation)

To launch the application use this prompt command:
```
tso
```

### Docs at:

<https://pcubillos.github.io/gen_tso/>

### Take a look:

<img alt="Gen_TSO" src="https://github.com/pcubillos/gen_tso/blob/master/docs/gen_tso_screenshot.png">

### Cite as:

Comming soon ...

